Module iterator

Module iterator 

Table bucket range iterator implementation.

Provides efficient iteration over bucket ranges for specific base keys by opening bucket-specific tables on demand.

Structs

TableBucketRangeIterator
Iterator over a range of buckets for a specific base key.
TableBucketRangeMultimapIterator
Iterator over a range of buckets for a specific base key in multimap tables.

Traits

TableBucketIterExt
Extension trait for table bucket iteration on read transactions.
TableBucketMultimapIterExt
Extension trait for table bucket iteration on read transactions for multimap tables.