TableBucketBuilder

Struct TableBucketBuilder 

pub struct TableBucketBuilder { /* private fields */ }
Builder for table bucket configuration and name resolution.

Implementations

Source

impl TableBucketBuilder

pub fn new( bucket_size: u64, table_prefix: impl Into<String>, ) -> Result<Self, BucketError>

Create a new builder with the specified bucket size and table prefix.

Arguments
  • bucket_size - Size of each bucket for integer division (must be > 0)
  • table_prefix - Prefix for bucket table names
pub fn bucket_size(&self) -> u64

Get the configured bucket size.

pub fn table_prefix(&self) -> &str

Get the configured table prefix.

pub fn bucket_for_sequence(&self, sequence: u64) -> u64

Compute the bucket for the given sequence.

pub fn bucket_table_name(&self, bucket: u64) -> &'static str

Resolve the bucket table name, caching and leaking the name string.

pub fn table_definition<K: Key + 'static, V: Value + 'static>( &self, bucket: u64, ) -> TableDefinition<'static, K, V>

Create a table definition for the given bucket.

pub fn multimap_table_definition<K: Key + 'static, V: Key + 'static>( &self, bucket: u64, ) -> MultimapTableDefinition<'static, K, V>

Create a multimap table definition for the given bucket.

pub fn merge<K, V>( &self, txn: &mut WriteTransaction, target: TableDefinition<'static, K, V>, start_bucket: u64, end_bucket: u64, ) -> Result<(), BucketError>
where K: Key + 'static, for<'b, 'b> V: Value + MergeableValue + 'static + From<V::SelfType<'b>> + Borrow<V::SelfType<'b>>,

Merge bucket tables into a single non-bucketed target table and delete the originals.

pub fn merge_all<K, V>( &self, txn: &mut WriteTransaction, target: TableDefinition<'static, K, V>, ) -> Result<(), BucketError>
where K: Key + 'static, for<'b, 'b> V: Value + MergeableValue + 'static + From<V::SelfType<'b>> + Borrow<V::SelfType<'b>>,

Merge all bucket tables discovered in the database into the target table.