pub struct PartitionedTable<V> { /* private fields */ }Expand description
Generic partitioned table that stores values in sharded segments.
This type provides the core storage infrastructure without knowing anything about specific value types. It handles the mechanics of:
- Sharding writes across multiple partitions
- Segmenting large values to control write amplification
- Optional meta table for O(1) head segment discovery
The V parameter represents the value handler type that knows how to
encode/decode and manipulate specific value types.
Implementations
Sourceimpl<V> PartitionedTable<V>
impl<V> PartitionedTable<V>
Sourcepub fn new(name: &'static str, config: PartitionConfig) -> Self
pub fn new(name: &'static str, config: PartitionConfig) -> Self
Sourcepub fn ensure_table_exists(&self, db: &Database) -> Result<()>
pub fn ensure_table_exists(&self, db: &Database) -> Result<()>
Sourcepub fn config(&self) -> &PartitionConfig
pub fn config(&self) -> &PartitionConfig
Returns the configuration.